@@ -15,7 +15,7 @@ AnyDataT = TypeVar("AnyDataT")
 
 
 class DataMixin(BaseModel, Generic[AnyDataT]):
-    data: AnyDataT = Field(..., description="Data.")
+    data: AnyDataT = Field(..., description="Data")
 
 
 ModelDataT = TypeVar("ModelDataT", bound=BaseModel)
