@@ -7,14 +7,15 @@ from .enums import Code as ErrorCode
 
 
 class ErrorType(BaseModel):
-    type: Annotated[ErrorTypeEnum, Field(..., description="Error type")] = (
-        ErrorTypeEnum.INTERNAL_SERVER_ERROR
-    )
+    type: Annotated[
+        ErrorTypeEnum,
+        Field(ErrorTypeEnum.INTERNAL_SERVER_ERROR, description="Error type"),
+    ] = ErrorTypeEnum.INTERNAL_SERVER_ERROR
 
 
 class ErrorSpec(StatusCode, ErrorType):
     status_code: Annotated[
-        int, Field(..., description="Status code", ge=100, le=600)
+        int, Field(500, description="Status code", ge=400, le=600)
     ] = 500
 
 
