@@ -1,6 +1,6 @@
 import traceback as tb
 from fastapi.responses import JSONResponse
-from typing import Any, Generic, Literal, Optional, Type, Union, overload
+from typing import Any, Generic, Literal, Type, Union, overload
 from uuid import uuid4
 from maleo.types.string import ListOfStrings, OptionalString
 from maleo.types.uuid import OptionalUUID
@@ -62,12 +62,12 @@ from ..response import (
     NotImplementedResponse,
     BadGatewayResponse,
     ServiceUnavailableResponse,
-    AnyErrorResponse,
+    OptionalAnyErrorResponse,
     ErrorResponseT,
     ResponseContext,
 )
-from ..security.authentication import OptionalAnyAuthenticationT
-from ..security.authorization import OptionalAuthorizationT
+from ..security.authentication import OptionalAnyAuthentication
+from ..security.authorization import OptionalAnyAuthorization
 from ..security.impersonation import OptionalImpersonation
 
 
@@ -75,8 +75,6 @@ class MaleoException(
     Exception,
     Generic[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -96,10 +94,10 @@ class MaleoException(
         operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
         connection_context: ConnectionContext,
-        authentication: OptionalAnyAuthenticationT = None,
-        authorization: OptionalAuthorizationT = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
-        response: Optional[AnyErrorResponse] = None,
+        response: OptionalAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -115,10 +113,10 @@ class MaleoException(
         operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT = None,
-        authorization: OptionalAuthorizationT = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
-        response: Optional[AnyErrorResponse] = None,
+        response: OptionalAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -134,10 +132,10 @@ class MaleoException(
         operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT = None,
-        authorization: OptionalAuthorizationT = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
-        response: Optional[AnyErrorResponse] = None,
+        response: OptionalAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -152,10 +150,10 @@ class MaleoException(
         operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT = None,
-        authorization: OptionalAuthorizationT = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
-        response: Optional[AnyErrorResponse] = None,
+        response: OptionalAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -170,10 +168,10 @@ class MaleoException(
         operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT = None,
-        authorization: OptionalAuthorizationT = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
-        response: Optional[AnyErrorResponse] = None,
+        response: OptionalAnyErrorResponse = None,
     ) -> None: ...
     @overload
     def __init__(
@@ -193,10 +191,10 @@ class MaleoException(
         operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT = None,
-        authorization: OptionalAuthorizationT = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
-        response: Optional[AnyErrorResponse] = None,
+        response: OptionalAnyErrorResponse = None,
     ) -> None: ...
     def __init__(
         self,
@@ -215,10 +213,10 @@ class MaleoException(
         operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT = None,
-        authorization: OptionalAuthorizationT = None,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
-        response: Optional[AnyErrorResponse] = None,
+        response: OptionalAnyErrorResponse = None,
     ) -> None:
         super().__init__(*args)
         self.details = details
@@ -271,62 +269,42 @@ class MaleoException(
     def operation(self) -> Union[
         CreateFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         FailedSystemOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         FailedWebSocketOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
     ]:
@@ -351,7 +329,10 @@ class MaleoException(
                 headers=response.headers.items(),
             )
 
-            return FailedRequestOperationFactory.generate(
+            return FailedRequestOperationFactory[
+                AnyErrorT,
+                ErrorResponseT,
+            ].generate(
                 self.operation_action,
                 application_context=self.application_context,
                 id=self.operation_id,
@@ -377,7 +358,10 @@ class MaleoException(
                     ErrorCode.BAD_REQUEST,
                     "Failed generating resource operation from MaleoException. Resource is not given",
                 )
-            return FailedResourceOperationFactory.generate(
+            return FailedResourceOperationFactory[
+                AnyErrorT,
+                ErrorResponseT,
+            ].generate(
                 self.operation_action,
                 application_context=self.application_context,
                 id=self.operation_id,
@@ -400,8 +384,6 @@ class MaleoException(
                 )
             return FailedSystemOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ](
                 application_context=self.application_context,
@@ -425,8 +407,6 @@ class MaleoException(
                 )
             return FailedWebSocketOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ](
                 application_context=self.application_context,
@@ -456,26 +436,18 @@ class MaleoException(
     ) -> Union[
         CreateFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
     ]: ...
@@ -487,26 +459,18 @@ class MaleoException(
     ) -> Union[
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
     ]: ...
@@ -515,17 +479,13 @@ class MaleoException(
         self,
         operation_type: Literal[OperationType.SYSTEM],
         /,
-    ) -> FailedSystemOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> FailedSystemOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     def generate_operation(
         self,
         operation_type: Literal[OperationType.WEBSOCKET],
         /,
-    ) -> FailedWebSocketOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> FailedWebSocketOperation[AnyErrorT, ErrorResponseT]: ...
     def generate_operation(
         self,
         operation_type: OperationType,
@@ -533,62 +493,42 @@ class MaleoException(
     ) -> Union[
         CreateFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedRequestOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         FailedSystemOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         FailedWebSocketOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
     ]:
@@ -599,7 +539,7 @@ class MaleoException(
                     "Failed generating operation for MaleoException ",
                     "due to mismatched operation_type. ",
                     f"Expected '{self.operation_type}' ",
-                    f"but received {operation_type}.",
+                    f"but received {operation_type}",
                 ),
             )
 
@@ -611,8 +551,6 @@ class MaleoException(
                 )
             return FailedSystemOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ](
                 application_context=self.application_context,
@@ -636,8 +574,6 @@ class MaleoException(
                 )
             return FailedWebSocketOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ](
                 application_context=self.application_context,
@@ -676,7 +612,10 @@ class MaleoException(
                     headers=response.headers.items(),
                 )
 
-                return FailedRequestOperationFactory.generate(
+                return FailedRequestOperationFactory[
+                    AnyErrorT,
+                    ErrorResponseT,
+                ].generate(
                     self.operation_action,
                     application_context=self.application_context,
                     id=self.operation_id,
@@ -697,7 +636,10 @@ class MaleoException(
                         ErrorCode.BAD_REQUEST,
                         "Failed generating resource operation from MaleoException. Resource is not given",
                     )
-                return FailedResourceOperationFactory.generate(
+                return FailedResourceOperationFactory[
+                    AnyErrorT,
+                    ErrorResponseT,
+                ].generate(
                     self.operation_action,
                     application_context=self.application_context,
                     id=self.operation_id,
@@ -717,14 +659,10 @@ class MaleoException(
 class ClientException(
     MaleoException[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
     Generic[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -734,11 +672,8 @@ class ClientException(
 class BadRequest(
     ClientException[
         BadRequestError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         BadRequestResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = BadRequestError
     response_cls = BadRequestResponse
@@ -747,11 +682,8 @@ class BadRequest(
 class Unauthorized(
     ClientException[
         UnauthorizedError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         UnauthorizedResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = UnauthorizedError
     response_cls = UnauthorizedResponse
@@ -760,11 +692,8 @@ class Unauthorized(
 class Forbidden(
     ClientException[
         ForbiddenError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ForbiddenResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = ForbiddenError
     response_cls = ForbiddenResponse
@@ -773,11 +702,8 @@ class Forbidden(
 class NotFound(
     ClientException[
         NotFoundError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         NotFoundResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = NotFoundError
     response_cls = NotFoundResponse
@@ -786,11 +712,8 @@ class NotFound(
 class MethodNotAllowed(
     ClientException[
         MethodNotAllowedError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         MethodNotAllowedResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = MethodNotAllowedError
     response_cls = MethodNotAllowedResponse
@@ -799,11 +722,8 @@ class MethodNotAllowed(
 class Conflict(
     ClientException[
         ConflictError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ConflictResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = ConflictError
     response_cls = ConflictResponse
@@ -812,11 +732,8 @@ class Conflict(
 class UnprocessableEntity(
     ClientException[
         UnprocessableEntityError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         UnprocessableEntityResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = UnprocessableEntityError
     response_cls = UnprocessableEntityResponse
@@ -825,11 +742,8 @@ class UnprocessableEntity(
 class TooManyRequests(
     ClientException[
         TooManyRequestsError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         TooManyRequestsResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = TooManyRequestsError
     response_cls = TooManyRequestsResponse
@@ -838,14 +752,10 @@ class TooManyRequests(
 class ServerException(
     MaleoException[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
     Generic[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -855,11 +765,8 @@ class ServerException(
 class InternalServerError(
     ServerException[
         InternalServerErrorSchema,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         InternalServerErrorResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = InternalServerErrorSchema
     response_cls = InternalServerErrorResponse
@@ -868,11 +775,8 @@ class InternalServerError(
 class NotImplemented(
     ServerException[
         NotImplementedError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         NotImplementedResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = NotImplementedError
     response_cls = NotImplementedResponse
@@ -881,11 +785,8 @@ class NotImplemented(
 class BadGateway(
     ServerException[
         BadGatewayError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         BadGatewayResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = BadGatewayError
     response_cls = BadGatewayResponse
@@ -894,17 +795,28 @@ class BadGateway(
 class ServiceUnavailable(
     ServerException[
         ServiceUnavailableError,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ServiceUnavailableResponse,
-    ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT],
+    ]
 ):
     error_cls = ServiceUnavailableError
     response_cls = ServiceUnavailableResponse
 
 
-exceptions = (
+AnyExceptionType = Union[
+    Type[BadRequest],
+    Type[Unauthorized],
+    Type[Forbidden],
+    Type[NotFound],
+    Type[MethodNotAllowed],
+    Type[Conflict],
+    Type[UnprocessableEntity],
+    Type[TooManyRequests],
+    Type[InternalServerError],
+    Type[NotImplemented],
+    Type[BadGateway],
+    Type[ServiceUnavailable],
+]
+AnyException = Union[
     BadRequest,
     Unauthorized,
     Forbidden,
@@ -917,4 +829,4 @@ exceptions = (
     NotImplemented,
     BadGateway,
     ServiceUnavailable,
-)
+]
