@@ -1,6 +1,6 @@
 from pydantic import BaseModel, Field
 from typing import Dict, Generic, Optional, TypeVar, Union
-from maleo.mixins.general import Success, Descriptor, Other
+from .mixins.general import Success, Descriptor, Other
 
 
 AnyMetadataT = TypeVar("AnyMetadataT")
