@@ -2,7 +2,7 @@ import traceback
 from logging import Logger
 from typing import Generic
 from maleo.logging.enums import Level
-from maleo.types.boolean import OptionalBoolean
+from maleo.types.boolean import BooleanT, OptionalBoolean
 from maleo.types.dict import (
     OptionalStringToStringDict,
     StringToAnyDict,
@@ -12,7 +12,7 @@ from maleo.utils.merger import merge_dicts
 from ..application import ApplicationContextMixin
 from ..connection import OptionalConnectionContextT, ConnectionContextMixin
 from ..error import OptionalAnyErrorT, ErrorMixin
-from ..mixins.general import Success, SuccessT
+from ..mixins.general import Success
 from ..resource import OptionalResourceT, ResourceMixin
 from ..response import (
     OptionalResponseContextT,
@@ -21,10 +21,10 @@ from ..response import (
     ResponseMixin,
 )
 from ..security.authentication import (
-    OptionalAnyAuthenticationT,
+    OptionalAnyAuthentication,
     AuthenticationMixin,
 )
-from ..security.authorization import OptionalAuthorizationT, AuthorizationMixin
+from ..security.authorization import OptionalAnyAuthorization, AuthorizationMixin
 from ..security.impersonation import OptionalImpersonation, ImpersonationMixin
 from .action import (
     ActionMixin,
@@ -38,11 +38,11 @@ class BaseOperation(
     ResponseContextMixin[OptionalResponseContextT],
     ResponseMixin[ResponseT],
     ImpersonationMixin[OptionalImpersonation],
-    AuthorizationMixin[OptionalAuthorizationT],
-    AuthenticationMixin[OptionalAnyAuthenticationT],
+    AuthorizationMixin[OptionalAnyAuthorization],
+    AuthenticationMixin[OptionalAnyAuthentication],
     ConnectionContextMixin[OptionalConnectionContextT],
     ErrorMixin[OptionalAnyErrorT],
-    Success[SuccessT],
+    Success[BooleanT],
     Summary,
     TimestampMixin,
     ResourceMixin[OptionalResourceT],
@@ -54,11 +54,9 @@ class BaseOperation(
     Generic[
         ActionT,
         OptionalResourceT,
-        SuccessT,
+        BooleanT,
         OptionalAnyErrorT,
         OptionalConnectionContextT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ResponseT,
         OptionalResponseContextT,
     ],
