@@ -2,12 +2,13 @@ from datetime import datetime, timezone
 from pydantic import BaseModel, Field, model_validator
 from typing import Annotated, Optional, Self
 from uuid import UUID
-from .enums import OperationType as OperationTypeEnum
+from ..mixins.identity import UUIDId
 from ..mixins.timestamp import ExecutionTimestamp, CompletionTimestamp, Duration
+from .enums import OperationType as OperationTypeEnum
 
 
-class Id(BaseModel):
-    id: Annotated[UUID, Field(..., description="Operation's id")]
+class Id(UUIDId[UUID]):
+    pass
 
 
 class OperationType(BaseModel):
