@@ -1,13 +1,11 @@
 from typing import Generic, Literal
+from maleo.types.boolean import BooleanT
 from ..connection import OptionalConnectionContext
 from ..error import (
     OptionalAnyErrorT,
     AnyErrorT,
 )
-from ..mixins.general import SuccessT
 from ..response import ResponseT, ErrorResponseT, SuccessResponseT
-from ..security.authentication import OptionalAnyAuthenticationT
-from ..security.authorization import OptionalAuthorizationT
 from .action.system import SystemOperationAction
 from .base import BaseOperation
 from .enums import OperationType
@@ -17,19 +15,15 @@ class SystemOperation(
     BaseOperation[
         SystemOperationAction,
         None,
-        SuccessT,
+        BooleanT,
         OptionalAnyErrorT,
         OptionalConnectionContext,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ResponseT,
         None,
     ],
     Generic[
-        SuccessT,
+        BooleanT,
         OptionalAnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ResponseT,
     ],
 ):
@@ -42,13 +36,9 @@ class FailedSystemOperation(
     SystemOperation[
         Literal[False],
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
-    Generic[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ],
+    Generic[AnyErrorT, ErrorResponseT],
 ):
     success: Literal[False] = False
 
@@ -57,11 +47,9 @@ class SuccessfulSystemOperation(
     SystemOperation[
         Literal[True],
         None,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         SuccessResponseT,
     ],
-    Generic[OptionalAnyAuthenticationT, OptionalAuthorizationT, SuccessResponseT],
+    Generic[SuccessResponseT],
 ):
     success: Literal[True] = True
     error: None = None
