@@ -52,7 +52,7 @@ class Resource(BaseModel):
 
 
 OptionalResource = Optional[Resource]
-OptionalResourceT = TypeVar("OptionalResourceT", bound=Optional[Resource])
+OptionalResourceT = TypeVar("OptionalResourceT", bound=OptionalResource)
 
 
 class ResourceMixin(BaseModel, Generic[OptionalResourceT]):
