@@ -13,7 +13,9 @@ from typing import (
     Union,
     overload,
 )
+from maleo.types.boolean import BooleanT
 from maleo.types.dict import StringToAnyDict
+from maleo.types.misc import StringOrStringEnumT
 from maleo.types.string import OptionalString
 from .data import DataPair, AnyDataT, ModelDataT
 from .error.descriptor import (
@@ -33,7 +35,7 @@ from .error.descriptor import (
 )
 from .error.enums import Code as ErrorCode
 from .metadata import AnyMetadataT, ModelMetadataT
-from .mixins.general import SuccessT, Success, CodeT, Descriptor
+from .mixins.general import Success, Descriptor
 from .pagination import OptionalPaginationT, PaginationT
 from .payload import (
     Payload,
@@ -95,10 +97,10 @@ class ResponseContextMixin(BaseModel, Generic[OptionalResponseContextT]):
 
 class Response(
     Payload[AnyDataT, OptionalPaginationT, AnyMetadataT],
-    Descriptor[CodeT],
-    Success[SuccessT],
+    Descriptor[StringOrStringEnumT],
+    Success[BooleanT],
     BaseModel,
-    Generic[SuccessT, CodeT, AnyDataT, OptionalPaginationT, AnyMetadataT],
+    Generic[BooleanT, StringOrStringEnumT, AnyDataT, OptionalPaginationT, AnyMetadataT],
 ):
     pass
 
@@ -229,6 +231,7 @@ AnyErrorResponse = Union[
     ServiceUnavailableResponse,
 ]
 ErrorResponseT = TypeVar("ErrorResponseT", bound=AnyErrorResponse)
+OptionalAnyErrorResponse = Optional[AnyErrorResponse]
 
 
 class ErrorFactory:
@@ -964,7 +967,7 @@ class OptionalMultipleDataResponse(
         )
 
 
-AllSuccessResponse = Union[
+AnySuccessResponse = Union[
     AnyDataResponse[ModelDataT, OptionalPaginationT, ModelMetadataT],
     NoDataResponse[ModelMetadataT],
     SingleDataResponse[ModelDataT, ModelMetadataT],
@@ -980,11 +983,11 @@ AllSuccessResponse = Union[
     DeleteMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
     OptionalMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
 ]
-SuccessResponseT = TypeVar("SuccessResponseT", bound=AllSuccessResponse)
+SuccessResponseT = TypeVar("SuccessResponseT", bound=AnySuccessResponse)
 
 
-AllResponse = Union[AnyErrorResponse, AllSuccessResponse]
-ResponseT = TypeVar("ResponseT", bound=AllResponse)
+AnyResponse = Union[AnyErrorResponse, AnySuccessResponse]
+ResponseT = TypeVar("ResponseT", bound=AnyResponse)
 
 
 class ResponseMixin(BaseModel, Generic[ResponseT]):
