@@ -1,10 +1,19 @@
 from collections.abc import Iterable, Sequence
 from Crypto.PublicKey.RSA import RsaKey
 from datetime import datetime, timedelta, timezone
-from enum import StrEnum
-from pydantic import BaseModel, Field, model_validator
-from typing import Generic, Literal, Optional, Self, Tuple, TypeVar, Union, overload
-from typing_extensions import Annotated
+from pydantic import BaseModel, Field, ValidationError, model_validator
+from typing import (
+    Annotated,
+    Generic,
+    Literal,
+    Optional,
+    Self,
+    Tuple,
+    TypeGuard,
+    TypeVar,
+    Union,
+    overload,
+)
 from uuid import UUID
 from maleo.crypto.token import decode, encode
 from maleo.enums.expiration import Expiration
@@ -13,7 +22,7 @@ from maleo.types.integer import OptionalInteger
 from maleo.types.misc import BytesOrString
 from maleo.types.string import ListOfStrings, OptionalListOfStrings, OptionalString
 from maleo.types.uuid import OptionalUUID
-from .enums import Domain
+from .enums import Domain, OptionalDomain, DomainT
 
 
 class TokenV1(BaseModel):
@@ -40,15 +49,26 @@ class TokenV1(BaseModel):
     exp_dt: Annotated[datetime, Field(..., description="Expired At Timestamp")]
     exp: Annotated[int, Field(..., description="Expired at")]
 
-
-class ConversionDestination(StrEnum):
-    BASE = "base"
-    TENANT = "tenant"
-    SYSTEM = "system"
-
     @classmethod
-    def choices(cls) -> ListOfStrings:
-        return [e.value for e in cls]
+    def from_string(
+        cls,
+        token: str,
+        *,
+        key: Union[RsaKey, BytesOrString],
+        audience: str | Iterable[str] | None = None,
+        subject: OptionalString = None,
+        issuer: str | Sequence[str] | None = None,
+        leeway: float | timedelta = 0,
+    ) -> "TokenV1":
+        obj = decode(
+            token,
+            key=key,
+            audience=audience,
+            subject=subject,
+            issuer=issuer,
+            leeway=leeway,
+        )
+        return cls.model_validate(obj)
 
 
 class Claim(BaseModel):
@@ -68,7 +88,6 @@ class Claim(BaseModel):
         return int(iat_dt.timestamp()), int(exp_dt.timestamp())
 
 
-DomainT = TypeVar("DomainT", bound=Domain)
 OrganizationT = TypeVar("OrganizationT", bound=OptionalUUID)
 
 
@@ -87,13 +106,21 @@ class GenericToken(
     def from_string(
         cls,
         token: str,
+        *,
         key: Union[RsaKey, BytesOrString],
         audience: str | Iterable[str] | None = None,
         subject: OptionalString = None,
         issuer: str | Sequence[str] | None = None,
         leeway: float | timedelta = 0,
-    ) -> "GenericToken[DomainT, OrganizationT]":
-        obj = decode(token, key, audience, subject, issuer, leeway)
+    ) -> Self:
+        obj = decode(
+            token,
+            key=key,
+            audience=audience,
+            subject=subject,
+            issuer=issuer,
+            leeway=leeway,
+        )
         return cls.model_validate(obj)
 
     @property
@@ -135,69 +162,6 @@ class GenericToken(
             )
 
 
-class BaseToken(GenericToken[Domain, OptionalUUID]):
-    d: Annotated[Domain, Field(..., description="Domain")]
-
-    @classmethod
-    def from_string(
-        cls,
-        token: str,
-        key: Union[RsaKey, BytesOrString],
-        audience: str | Iterable[str] | None = None,
-        subject: OptionalString = None,
-        issuer: str | Sequence[str] | None = None,
-        leeway: float | timedelta = 0,
-    ) -> "BaseToken":
-        obj = decode(token, key, audience, subject, issuer, leeway)
-        return cls.model_validate(obj)
-
-    @classmethod
-    def new(
-        cls,
-        *,
-        sub: UUID,
-        d: Domain,
-        o: OptionalUUID = None,
-        r: ListOfStrings,
-        iss: OptionalString = None,
-        aud: OptionalString = None,
-        iat_dt: OptionalDatetime = None,
-        exp_in: Expiration = Expiration.EXP_15MN,
-    ) -> "BaseToken":
-        iat, exp = cls.new_timestamp(iat_dt, exp_in)
-        return cls(iss=iss, sub=sub, aud=aud, exp=exp, iat=iat, d=d, o=o, r=r)
-
-    @overload
-    def to_string(
-        self,
-        key: RsaKey,
-    ) -> str: ...
-    @overload
-    def to_string(
-        self,
-        key: BytesOrString,
-        *,
-        password: OptionalString = None,
-    ) -> str: ...
-    def to_string(
-        self,
-        key: Union[RsaKey, BytesOrString],
-        *,
-        password: OptionalString = None,
-    ) -> str:
-        if isinstance(key, RsaKey):
-            return encode(
-                payload=self.model_dump(mode="json", exclude_none=True),
-                key=key,
-            )
-        else:
-            return encode(
-                payload=self.model_dump(mode="json", exclude_none=True),
-                key=key,
-                password=password,
-            )
-
-
 class TenantToken(GenericToken[Literal[Domain.TENANT], UUID]):
     d: Annotated[Literal[Domain.TENANT], Field(Domain.TENANT, description="Domain")] = (
         Domain.TENANT
@@ -226,9 +190,6 @@ class TenantToken(GenericToken[Literal[Domain.TENANT], UUID]):
         iat, exp = cls.new_timestamp(iat_dt, exp_in)
         return cls(iss=iss, sub=sub, aud=aud, exp=exp, iat=iat, o=o, r=r)
 
-    def to_base(self) -> BaseToken:
-        return BaseToken.model_validate(self.model_dump())
-
 
 class SystemToken(GenericToken[Literal[Domain.SYSTEM], None]):
     d: Annotated[Literal[Domain.SYSTEM], Field(Domain.SYSTEM, description="Domain")] = (
@@ -258,11 +219,8 @@ class SystemToken(GenericToken[Literal[Domain.SYSTEM], None]):
         iat, exp = cls.new_timestamp(iat_dt, exp_in)
         return cls(iss=iss, sub=sub, aud=aud, exp=exp, iat=iat, r=r)
 
-    def to_base(self) -> BaseToken:
-        return BaseToken.model_validate(self.model_dump())
 
-
-AnyToken = Union[BaseToken, TenantToken, SystemToken]
+AnyToken = Union[TenantToken, SystemToken]
 AnyTokenT = TypeVar("AnyTokenT", bound=AnyToken)
 OptionalAnyToken = Optional[AnyToken]
 OptionalAnyTokenT = TypeVar("OptionalAnyTokenT", bound=OptionalAnyToken)
@@ -272,53 +230,143 @@ class TokenMixin(BaseModel, Generic[OptionalAnyTokenT]):
     token: OptionalAnyTokenT = Field(..., description="Token")
 
 
-@overload
-def convert(
-    destination: Literal[ConversionDestination.BASE],
-    *,
-    token: Union[TenantToken, SystemToken],
-) -> BaseToken: ...
-@overload
-def convert(
-    destination: Literal[ConversionDestination.TENANT],
-    *,
-    token: BaseToken,
-) -> TenantToken: ...
-@overload
-def convert(
-    destination: Literal[ConversionDestination.SYSTEM],
-    *,
-    token: BaseToken,
-) -> SystemToken: ...
-def convert(
-    destination: ConversionDestination,
-    *,
-    token: AnyToken,
-) -> AnyToken:
-    if destination is ConversionDestination.BASE:
-        if isinstance(token, SystemToken):
-            return BaseToken.model_validate(token.model_dump())
-        elif isinstance(token, TenantToken):
-            return BaseToken.model_validate(token.model_dump())
-        elif isinstance(token, BaseToken):
-            return token
-    elif destination is ConversionDestination.TENANT:
-        if isinstance(token, SystemToken):
-            raise TypeError(
-                "Failed converting SystemToken to TenantToken",
-                "Both tokens can not be converted into one another",
-            )
-        elif isinstance(token, TenantToken):
-            return token
-        elif isinstance(token, BaseToken):
-            return TenantToken.model_validate(token.model_dump())
-    elif destination is ConversionDestination.SYSTEM:
-        if isinstance(token, SystemToken):
-            return token
-        elif isinstance(token, TenantToken):
-            raise TypeError(
-                "Failed converting TenantToken to SystemToken",
-                "Both tokens can not be converted into one another",
-            )
-        elif isinstance(token, BaseToken):
-            return SystemToken.model_validate(token.model_dump())
+def is_tenant(token: AnyToken) -> TypeGuard[TenantToken]:
+    return (
+        isinstance(token, TenantToken)
+        and token.d is Domain.TENANT
+        and token.o is not None
+    )
+
+
+def is_system(token: AnyToken) -> TypeGuard[SystemToken]:
+    return (
+        isinstance(token, SystemToken) and token.d is Domain.SYSTEM and token.o is None
+    )
+
+
+class Factory:
+    @overload
+    @staticmethod
+    def from_string(
+        token: str,
+        domain: Literal[Domain.TENANT],
+        *,
+        key: Union[RsaKey, BytesOrString],
+        audience: str | Iterable[str] | None = None,
+        subject: OptionalString = None,
+        issuer: str | Sequence[str] | None = None,
+        leeway: float | timedelta = 0,
+    ) -> TenantToken: ...
+    @overload
+    @staticmethod
+    def from_string(
+        token: str,
+        domain: Literal[Domain.SYSTEM],
+        *,
+        key: Union[RsaKey, BytesOrString],
+        audience: str | Iterable[str] | None = None,
+        subject: OptionalString = None,
+        issuer: str | Sequence[str] | None = None,
+        leeway: float | timedelta = 0,
+    ) -> SystemToken: ...
+    @overload
+    @staticmethod
+    def from_string(
+        token: str,
+        domain: None = None,
+        *,
+        key: Union[RsaKey, BytesOrString],
+        audience: str | Iterable[str] | None = None,
+        subject: OptionalString = None,
+        issuer: str | Sequence[str] | None = None,
+        leeway: float | timedelta = 0,
+    ) -> AnyToken: ...
+    @staticmethod
+    def from_string(
+        token: str,
+        domain: OptionalDomain = None,
+        *,
+        key: Union[RsaKey, BytesOrString],
+        audience: str | Iterable[str] | None = None,
+        subject: OptionalString = None,
+        issuer: str | Sequence[str] | None = None,
+        leeway: float | timedelta = 0,
+    ) -> AnyToken:
+        validated_token = None
+        models = (TokenV1, TenantToken, SystemToken)
+        for model in models:
+            try:
+                validated_token = model.from_string(
+                    token,
+                    key=key,
+                    audience=audience,
+                    subject=subject,
+                    issuer=issuer,
+                    leeway=leeway,
+                )
+            except ValidationError:
+                continue
+        if validated_token is None:
+            raise ValueError("Unable to validate raw token into known token model")
+
+        if isinstance(validated_token, (TenantToken, SystemToken)):
+            result_token = validated_token
+        else:
+            if validated_token.sr == "administrator":
+                if (
+                    validated_token.o_i is not None
+                    or validated_token.o_uu is not None
+                    or validated_token.o_k is not None
+                    or validated_token.o_ot is not None
+                    or validated_token.uor is not None
+                ):
+                    raise ValueError(
+                        "All organization-related claims must be None for System token"
+                    )
+                result_token = SystemToken(
+                    iss=validated_token.iss,
+                    sub=validated_token.u_uu,
+                    aud=None,
+                    exp=validated_token.exp,
+                    iat=validated_token.iat,
+                    r=["administrator", "user"],
+                )
+            elif validated_token.sr == "user":
+                if (
+                    validated_token.o_i is None
+                    or validated_token.o_uu is None
+                    or validated_token.o_k is None
+                    or validated_token.o_ot is None
+                    or validated_token.uor is None
+                ):
+                    raise ValueError(
+                        "All organization-related claims can not be None for Tenant Token"
+                    )
+                result_token = TenantToken(
+                    iss=validated_token.iss,
+                    sub=validated_token.u_uu,
+                    aud=None,
+                    exp=validated_token.exp,
+                    iat=validated_token.iat,
+                    o=validated_token.o_uu,
+                    r=validated_token.uor,
+                )
+            else:
+                raise ValueError(
+                    f"Claim 'sr' can only be either 'administrator' or 'user' but received {validated_token.sr}"
+                )
+
+        if domain is None:
+            return result_token
+        elif domain is Domain.TENANT:
+            if not is_tenant(result_token):
+                raise ValueError(
+                    "Failed parsing Tenant Token from string, raw token did not qualify as Tenant Token"
+                )
+            return result_token
+        elif domain is Domain.SYSTEM:
+            if not is_system(result_token):
+                raise ValueError(
+                    "Failed parsing System token from string, raw token did not qualify as System Token"
+                )
+            return result_token
